{% extends 'django_dzenlog/base.html' %}
{% load i18n dzenlog_tags %}

{% block head %}
    {{ block.super }}
    <link rel="alternate" type="application/rss+xml" title="{% trans "All posts" %}" href="{% call all_feeds_url slug="rss" %}" />
    <link rel="alternate" type="application/rss+xml" title="{% trans "Posts with this type and tags" %}" href="{% call feeds_url slug="rss" %}" />
{% endblock %}

{% block content %}
    <div class="b-tag-cloud">
    {% for tag in object_list %}
        <a class="fs-{{tag.font_size}}" href="{% call bytag_url tag.name %}">{{tag.name}}</a>
    {% endfor %}
    </div>
{% endblock %}

