DEBUG = True
TEMPLATE_DEBUG = DEBUG

DATABASE_ENGINE = 'mysql'           # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
DATABASE_NAME = 'dzenlog'             # Or path to database file if using sqlite3.
DATABASE_USER = 'root'             # Not used with sqlite3.
