{% extends 'django_dzenlog/base.html' %}
{% load i18n dzenlog_tags %}

{% block head %}
    {{ block.super }}
    <link rel="alternate" type="application/rss+xml" title="{% trans "All posts" %}" href="{% call all_feeds_url slug="rss" %}" />
    <link rel="alternate" type="application/rss+xml" title="{% trans "Posts with this type and tags" %}" href="{% call feeds_url slug="rss", param=tags_slug %}" />
{% endblock %}

{% block content %}
    {% if object_list %}
        {% for object in object_list %}
            {% call object.render bytag_url=bytag_url,list_view=1 %}
        {% endfor %}
    {% else %}
        <p>{% trans 'This blog is empty.' %}</p>
    {% endif %}
{% endblock %}
